pub fn basic_from_montgomery<T>(
a_mont: T,
modulus: T,
n_prime: T,
r_bits: usize,
) -> TExpand description
Convert from Montgomery form (Basic): (a * R) -> a mod N Uses Montgomery reduction algorithm with legacy R > N semantics.
Warning: This function can overflow for large moduli where m * N exceeds
the type width. For overflow-free reduction, use wide_from_montgomery
which uses wide-REDC with R = 2^W.